@@ -83,6 +83,14 @@ def zip_dir(zip_name, dir_path):
             myzip.write(fname, fname.replace(dir_path, arch).replace("\\", "/"))
 
 
+def to_excel(sheets, path):
+    writer = pd.ExcelWriter(path, engine="openpyxl")
+    for sheet_name in sheets.keys():
+        sheets[sheet_name].to_excel(excel_writer=writer, sheet_name=sheet_name, encoding="gbk",index=False)
+    writer.save()
+    writer.close()
+
+
 if __name__ == "__main__":
     mylog = log()
     mylog.logger.debug("haha")
